@@ -463,7 +463,10 @@ normalizeBetweenArrays <- function(object, method=NULL, targets=NULL, ...) {
 
 #	Treat EListRaw objects as matrices
 	if(is(object,"EListRaw")) {
-		object$E <- log2(Recall(object$E,method=method,...))
+		if(method=="cyclicloess")
+			object$E <- Recall(log2(object$E),method=method,...)
+		else
+			object$E <- log2(Recall(object$E,method=method,...))
 		object <- new("EList",unclass(object))
 		return(object)
 	}
@@ -624,17 +627,15 @@ normalizeMedianValues <- function(x)
 	t(t(x)/cmed)
 }
 
-normalizeCyclicLoess <- function(x, weights = NULL, span=0.4, iterations = 3)
+normalizeCyclicLoess <- function(x, weights = NULL, span=0.7, iterations = 3)
 #	Cyclic loess normalization of columns of matrix
 #	incorporating probes weights.
 #	Yunshun (Andy) Chen and Gordon Smyth
-#	14 April 2010.  Last modified 22 April 2010.
+#	14 April 2010.  Last modified 17 August 2011.
 {
 	y <- as.matrix(x)
-	if(is.null(weights))
-		weights <- rep(1,nrow(y))
-	for (k in 1:iterations) for (i in 1:(ncol(y)-1)) for (j in (i+1):ncol(y))
-	{
+	for (k in 1:iterations)
+	for (i in 1:(ncol(y)-1)) for (j in (i+1):ncol(y)) {
 		m <- y[,j] - y[,i]
 		a <- .5*(y[,j] + y[,i])
 		fit <- loessFit(m, a, weights = weights, span = span)
